# POCS-based Clustering Algorithm 

Official Implementation of the POCS-based Clustering Algorithm, a Clustering Method based on Projection Onto Convex Set.

## I. Introduction

 - Paper: [POCS-based Clustering Algorithm](https://arxiv.org/abs/2208.08888) (in Proceedings of The International Workshop on Intelligent Systems 2022 (IWIS 2022), Ulsan, South Korea, August 17-19, 2022)

 - Authors: [Le-Anh Tran](https://scholar.google.com/citations?user=WzcUE5YAAAAJ&hl=en), [Dong-Chul Park](https://ieeexplore.ieee.org/author/37275453300) et al.
 - Blog: (will be available soon)

## II. Usage
1. Demo with Jupyter Notebook:

    Notebook: [pocs-based-clustering-demo.ipynb](https://github.com/tranleanh/pocs-based-clustering/blob/main/pocs-based-clustering-demo.ipynb)    
    
2. Installation

    (will be available soon)    

## III. Results

Results on [Clustering basic benchmark](https://cs.joensuu.fi/sipu/datasets/)

<p align="center">
<img src="docs/results_synthetic_datasets.jpg" width="1000">
</p>


Have fun!

LA Tran

Created: 04.2022
